@@ -134,6 +134,8 @@ class Mnemosyne(Component):
           "Mnemosyne1XML"),
          ("mnemosyne.libmnemosyne.file_formats.mnemosyne2_cards",
           "Mnemosyne2Cards"),
+         ("mnemosyne.libmnemosyne.file_formats.mnemosyne2_db",
+          "Mnemosyne2Db"),         
          ("mnemosyne.libmnemosyne.file_formats.tsv",
           "Tsv"),
          ("mnemosyne.libmnemosyne.file_formats.supermemo_7_txt",
@@ -182,7 +184,7 @@ class Mnemosyne(Component):
         # Upgrade config if needed.
         if automatic_upgrades:
             from mnemosyne.libmnemosyne.upgrades.upgrade3 import Upgrade3
-            Upgrade3(self.component_manager).run()             
+            Upgrade3(self.component_manager).run() 
         self.activate_components()
         register_component_manager(self.component_manager,
             self.config()["user_id"])
@@ -229,7 +231,7 @@ class Mnemosyne(Component):
         self.main_widget().activate()
 
     def register_components(self):
-
+        
         """We register all components, but don't activate them yet, because in
         order to activate certain components, certain other components already
         need to be registered. Also, the activation needs to happen in a
@@ -320,7 +322,11 @@ class Mnemosyne(Component):
         path = expand_path(filename, self.config().data_dir)
         try:
             if not os.path.exists(path):
-                self.database().new(path)
+                try:
+                    self.database().new(path)
+                except:
+                    from mnemosyne.libmnemosyne.translator import _
+                    raise RuntimeError(_("Previous drive letter no longer available."))
             else:
                 self.database().load(path)
             self.controller().update_title()
