@@ -127,6 +127,7 @@ class Configuration(Component, dict):
              "single_database_help_shown": False,
              "save_database_help_shown": False,
              "find_duplicates_help_shown": False,
+             "star_help_shown": False,
              "start_card_browser_sorted": False,
              "day_starts_at": 3,
              "save_after_n_reps": 10,
@@ -186,7 +187,7 @@ class Configuration(Component, dict):
             # Don't log when reading the settings from file during startup.
             if self.log().active:
                 self.log().edited_setting(key)
-        dict.__setitem__(self, key, value) 
+        dict.__setitem__(self, key, value)
 
     def load(self):
         filename = os.path.join(self.config_dir, "config.db")
@@ -210,7 +211,12 @@ class Configuration(Component, dict):
             pass
         # Set config settings.
         for cursor in con.execute("select key, value from config"):
-            self[cursor[0]] = eval(cursor[1])     
+            try:
+                self[cursor[0]] = eval(cursor[1])
+            except:
+                # This can fail if we are running headless now after running
+                # the GUI previously.
+                pass
         con.close()
 
     def save(self):
