@@ -411,11 +411,16 @@ class DefaultController(Controller):
     def star_current_card(self):
         self.stopwatch().pause()
         self.flush_sync_server()
+        if self.config()["star_help_shown"] == False:
+            self.main_widget().show_information(\
+_("This will add a tag 'Starred' to the current card, so that you can find it back easily, e.g. to edit it on a desktop."))
+            self.config()["star_help_shown"] = True        
         db = self.database()
         review_controller = self.review_controller()
         tag = db.get_or_create_tag_with_name(_("Starred"))
-        db.add_tag_to_cards_with_internal_ids\
-            (tag, [review_controller.card._id])
+        _sister_card_ids = [card._id for card in \
+            self.database().cards_from_fact(review_controller.card.fact)]
+        db.add_tag_to_cards_with_internal_ids(tag, _sister_card_ids)
         review_controller.card = \
             db.card(review_controller.card._id, is_id_internal=True)
         review_controller.update_dialog(redraw_all=True)
@@ -559,12 +564,12 @@ _("It is recommended to put all your cards in a single database. Using tags to d
             import shutil
             shutil.rmtree(filename + "_media")
         db.new(filename)
+        self.main_widget().close_progress()
         db.load(self.config()["last_database"])
         self.log().loaded_database()
         self.review_controller().reset()
         self.review_controller().update_dialog()
         self.update_title()
-        self.main_widget().close_progress()
         self.stopwatch().unpause()
 
     def show_open_file_dialog(self):
@@ -579,9 +584,15 @@ _("It is recommended to put all your cards in a single database. Using tags to d
             self.stopwatch().unpause()
             return
         if filename.endswith(".cards"):
+            self.stopwatch().unpause()
             self.main_widget().show_information(\
 _("'*.cards' files are not separate databases, but need to be imported in your current database through 'File - Import'."))
             return
+        if filename.endswith("config.db"):
+            self.stopwatch().unpause()
+            self.main_widget().show_information(\
+                _("The configuration database is not used to store cards."))
+            return            
         if filename.startswith(os.path.join(data_dir, "backups")):
             result = self.main_widget().show_question(\
                 _("Do you want to replace your current database with one restored from this backup?\nNote that this will result in conflicts during the next sync, which need to be resolved by a full sync."),
@@ -647,6 +658,11 @@ _("Your database will be autosaved before exiting. Also, it is saved every coupl
         if not filename:
             self.stopwatch().unpause()
             return
+        if filename.endswith("config.db"):
+            self.main_widget().show_information(\
+_("The configuration database cannot be used to store cards."))
+            self.stopwatch().unpause()
+            return          
         if not filename.endswith(suffix):
             filename += suffix
         try:
@@ -757,10 +773,16 @@ _("Your database will be autosaved before exiting. Also, it is saved every coupl
         self.stopwatch().unpause()
 
     def show_activate_cards_dialog(self):
+        self.show_activate_cards_dialog_pre()
+        self.show_activate_cards_dialog_post()
+         
+    def show_activate_cards_dialog_pre(self):
         self.stopwatch().pause()
         self.flush_sync_server()
         self.component_manager.current("activate_cards_dialog")\
             (self.component_manager).activate()
+        
+    def show_activate_cards_dialog_post(self):       
         review_controller = self.review_controller()
         review_controller.reset_but_try_to_keep_current_card()
         review_controller.update_status_bar_counters()
@@ -922,11 +944,17 @@ _("This will tag all the cards in a given card type which have the same question
         return dialog.values()
 
     def show_sync_dialog(self):
+        self.show_sync_dialog_pre()
+        self.show_sync_dialog_post()
+        
+    def show_sync_dialog_pre(self): 
         self.stopwatch().pause()
         self.flush_sync_server()
         self.database().save()
         self.component_manager.current("sync_dialog")\
             (self.component_manager).activate()
+        
+    def show_sync_dialog_post(self):
         self.database().save()
         self.log().saved_database()
         self.review_controller().reset_but_try_to_keep_current_card()
@@ -950,7 +978,7 @@ _("This will tag all the cards in a given card type which have the same question
             self.database().store_pregenerated_data
         client.do_backup = self.config()["backup_before_sync"]
         client.upload_science_logs = self.config()["upload_science_logs"]
-        try:
+        try:         
             client.sync(server, port, username, password)
         finally:
             client.database.release_connection()
