@@ -349,6 +349,8 @@ class SQLite(Database, SQLiteSync, SQLiteMedia, SQLiteLogging,
         if self.is_loaded():
             self.unload()
         self._path = expand_path(path, self.config().data_dir)
+        if not os.path.exists(self._path):
+            return new(path)
         # Check database version.
         try:
             sql_res = self.con.execute("""select value from global_variables
@@ -576,6 +578,7 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
         return tags
 
     def add_tag(self, tag):
+        tag.name = tag.name.replace(",", " - ")
         self.con.execute("""insert into tags(name, extra_data, id)
             values(?,?,?)""", (tag.name,
             self._repr_extra_data(tag.extra_data), tag.id))
@@ -1094,6 +1097,9 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
             repr([fact_view.id for fact_view in card_type.fact_views]),
             repr(card_type.keyboard_shortcuts),
             self._repr_extra_data(card_type.extra_data)))
+        # When we are syncing/merging, make sure we correctly insert the
+        # class in the inheritance hierarchy.
+        card_type = self.card_type(card_type.id, is_id_internal=False)
         self.component_manager.register(card_type)
         self.log().added_card_type(card_type)
         # When syncing (but not when importing), don't bother to check for
