@@ -19,8 +19,7 @@ from mnemosyne.libmnemosyne.utils import expand_path
 from mnemosyne.libmnemosyne.card_type import CardType
 from mnemosyne.libmnemosyne.fact_view import FactView
 
-re_src = re.compile(r"""(src|data)=['\"](.+?)['\"]""", 
-                    re.DOTALL | re.IGNORECASE)
+re_src = re.compile(r"""(src|data)=\"(.+?)\"""", re.DOTALL | re.IGNORECASE)
 
 # Simple named-tuple like class, to avoid the expensive creation a full card
 # object (Python 2.5 does not yet have a named tuple).
@@ -261,7 +260,7 @@ class SQLiteSync(object):
             _fact_id from cards where active=1) and value like '%src=%'"""):
             for match in re_src.finditer(result[0]):
                 active_objects["media_filenames"].add(match.group(2))
-        return active_objects
+        return active_objects     
 
     def set_extra_tags_on_import(self, tags):
         self.extra_tags_on_import = tags
