@@ -26,12 +26,15 @@ class Mnemosyne2Cards(FileFormat):
     import_possible = True
     export_possible = True
 
-    def do_export(self, filename):
+    def do_export(self, filename, used_for_merging_dbs=False):
         self.orig_dir = os.getcwd()
         if not os.path.isabs(filename):
             filename = os.path.join(self.config()["export_dir"], filename)
         os.chdir(os.path.dirname(filename))
-        metadata = self.controller().show_export_metadata_dialog()
+        if used_for_merging_dbs is True:
+            metadata = {}
+        else:
+            metadata = self.controller().show_export_metadata_dialog()
         if metadata is None:  # Cancelled.
             os.chdir(self.orig_dir)
             return -1
@@ -42,20 +45,23 @@ class Mnemosyne2Cards(FileFormat):
         metadata_file.close()
         db = self.database()
         w = self.main_widget()
-        w.set_progress_text(_("Exporting cards..."))
-        active_objects = db.active_objects_to_export()
         # Generate log entries.
+        if used_for_merging_dbs:
+            w.set_progress_text(_("Extracting cards..."))
+        else:
+            w.set_progress_text(_("Exporting cards..."))
+        active_objects = db.active_objects_to_export()
         number_of_entries = len(active_objects["tags"]) + \
             len(active_objects["fact_view_ids"]) + \
             len(active_objects["card_type_ids"]) + \
             len(active_objects["media_filenames"]) + \
             len(active_objects["_card_ids"]) + \
             len(active_objects["_fact_ids"])
-        w.set_progress_range(number_of_entries)
-        w.set_progress_update_interval(number_of_entries/20)
         xml_file = file("cards.xml", "w")
         xml_format = XMLFormat()
         xml_file.write(xml_format.log_entries_header(number_of_entries))
+        w.set_progress_range(number_of_entries)
+        w.set_progress_update_interval(number_of_entries/20)
         for tag in active_objects["tags"]:
             log_entry = LogEntry()
             log_entry["type"] = EventTypes.ADDED_TAG
@@ -130,15 +136,26 @@ class Mnemosyne2Cards(FileFormat):
             log_entry["fact"] = card.fact.id
             log_entry["fact_v"] = card.fact_view.id
             log_entry["tags"] = ",".join([tag.id for tag in card.tags])
-            log_entry["gr"] = -1
-            log_entry["e"] = 2.5
-            log_entry["ac_rp"] = 0
-            log_entry["rt_rp"] = 0
-            log_entry["lps"] = 0
-            log_entry["ac_rp_l"] = 0
-            log_entry["rt_rp_l"] = 0
-            log_entry["l_rp"] = -1
-            log_entry["n_rp"] = -1
+            if used_for_merging_dbs:
+                log_entry["gr"] = card.grade
+                log_entry["e"] = card.easiness
+                log_entry["ac_rp"] = card.acq_reps
+                log_entry["rt_rp"] = card.ret_reps
+                log_entry["lps"] = card.lapses
+                log_entry["ac_rp_l"] = card.acq_reps_since_lapse
+                log_entry["rt_rp_l"] = card.ret_reps_since_lapse
+                log_entry["l_rp"] = card.last_rep
+                log_entry["n_rp"] = card.next_rep                
+            else:
+                log_entry["gr"] = -1
+                log_entry["e"] = 2.5
+                log_entry["ac_rp"] = 0
+                log_entry["rt_rp"] = 0
+                log_entry["lps"] = 0
+                log_entry["ac_rp_l"] = 0
+                log_entry["rt_rp_l"] = 0
+                log_entry["l_rp"] = -1
+                log_entry["n_rp"] = -1
             if card.extra_data:
                 log_entry["extra"] = repr(card.extra_data)
             xml_file.write(xml_format.\
@@ -152,7 +169,10 @@ class Mnemosyne2Cards(FileFormat):
         zip_file.write("cards.xml")
         zip_file.write("METADATA")
         w.close_progress()
-        w.set_progress_text(_("Bundling media files..."))
+        if used_for_merging_dbs:
+            w.set_progress_text(_("Extracting media files..."))
+        else:
+            w.set_progress_text(_("Bundling media files..."))
         number_of_media_files = len(active_objects["media_filenames"])
         w.set_progress_range(number_of_media_files)
         w.set_progress_update_interval(number_of_media_files/100)
@@ -175,7 +195,7 @@ class Mnemosyne2Cards(FileFormat):
         os.chdir(self.orig_dir)
         w.close_progress()
 
-    def do_import(self, filename, extra_tag_names=None):
+    def do_import(self, filename, extra_tag_names=None, show_metadata=True):
         FileFormat.do_import(self, filename, extra_tag_names)
         if not extra_tag_names:
             extra_tags = []
@@ -183,20 +203,22 @@ class Mnemosyne2Cards(FileFormat):
             extra_tags = [self.database().get_or_create_tag_with_name(\
                 tag_name.strip()) for tag_name in extra_tag_names.split(",")]
         self.database().set_extra_tags_on_import(extra_tags)
+        # Extract zipfile. 
         w = self.main_widget()
-        w.set_progress_text(_("Importing cards..."))
-        # Extract zipfile.
+        w.set_progress_text(_("Decompressing..."))
         zip_file = zipfile.ZipFile(filename, "r")
         zip_file.extractall(self.database().media_dir())
-        # Show metadata
+        # Show metadata.          
         metadata_filename = os.path.join(\
-            self.database().media_dir(), "METADATA")
-        metadata = {}
-        for line in file(metadata_filename):
-            key, value = line.split(":", 1)
-            metadata[key] = value.replace("<br>", "\n")
-        self.controller().show_export_metadata_dialog(metadata, read_only=True)
+                self.database().media_dir(), "METADATA")
+        if show_metadata:
+            metadata = {}
+            for line in file(metadata_filename):
+                key, value = line.split(":", 1)
+                metadata[key] = value.replace("<br>", "\n")
+            self.controller().show_export_metadata_dialog(metadata, read_only=True)
         # Parse XML.
+        w.set_progress_text(_("Importing cards..."))
         self.database().card_types_to_instantiate_later = set()
         xml_filename = os.path.join(self.database().media_dir(), "cards.xml")
         element_loop = XMLFormat().parse_log_entries(file(xml_filename, "r"))
@@ -214,5 +236,3 @@ class Mnemosyne2Cards(FileFormat):
         os.remove(xml_filename)
         os.remove(metadata_filename)
         w.close_progress()
-
-
