@@ -55,9 +55,17 @@ def copyfile(src, dst):
             if stat.S_ISFIFO(st.st_mode):
                 raise SpecialFileError("`%s` is a named pipe" % fn)
 
-    with open(src, 'rb') as fsrc:
-        with open(dst, 'wb') as fdst:
-            copyfileobj(fsrc, fdst)
+    fsrc = None
+    fdst = None
+    try:
+        fsrc = open(src, 'rb')
+        fdst = open(dst, 'wb')
+        copyfileobj(fsrc, fdst)
+    finally:
+        if fdst:
+            fdst.close()
+        if fsrc:
+            fsrc.close()
 
 def copymode(src, dst):
     """Copy mode bits from src to dst"""
@@ -143,7 +151,7 @@ def copy_file_to_dir(filename, dirname):
     dirname = os.path.abspath(dirname)
     if filename.startswith(dirname):
         return contract_path(filename, dirname)
-    dest_path = os.path.join(dirname, os.path.basename(filename))
+    dest_path = os.path.join(dirname, os.path.basename(filename.replace(':', '-')))
     if os.path.exists(dest_path):  # Rename it to something unique.
         prefix, suffix = dest_path.rsplit(".", 1)
         count = 0
@@ -285,4 +293,3 @@ def localhost_IP():
     s = realsocket(socket.AF_INET, socket.SOCK_DGRAM)
     s.connect(("google.com", 8000))
     return s.getsockname()[0]
-
