@@ -133,7 +133,7 @@ class QAOptimalSplit(object):
                     answer_stretch = required_answer_height
                     question_stretch = total_height_available - answer_stretch
                     if question_stretch < 50:
-                        question_stretch = 50
+                        question_stretch = 50        
         self.vertical_layout.setStretchFactor(\
             self.question_box, question_stretch + self.stretch_offset)
         self.vertical_layout.setStretchFactor(\
@@ -182,7 +182,8 @@ class QAOptimalSplit(object):
 class ReviewWdgt(QtGui.QWidget, QAOptimalSplit, Ui_ReviewWdgt, ReviewWidget):
 
     auto_focus_grades = True
-
+    number_keys_show_answer = True
+     
     def __init__(self, component_manager):
         ReviewWidget.__init__(self, component_manager)
         parent = self.main_widget()
@@ -233,7 +234,8 @@ class ReviewWdgt(QtGui.QWidget, QAOptimalSplit, Ui_ReviewWdgt, ReviewWidget):
             QtCore.Qt.Key_2, QtCore.Qt.Key_3, QtCore.Qt.Key_4,
             QtCore.Qt.Key_5] and \
             self.review_controller().is_question_showing():
-                self.show_answer()
+                if self.number_keys_show_answer:
+                    self.show_answer()
         elif not event.isAutoRepeat() and event.key() \
             == QtCore.Qt.Key_QuoteLeft and \
             not self.review_controller().is_question_showing():
@@ -274,7 +276,8 @@ class ReviewWdgt(QtGui.QWidget, QAOptimalSplit, Ui_ReviewWdgt, ReviewWidget):
         </td></tr></table></body></html>"""
 
     def scroll_down(self):
-        if self.review_controller().is_question_showing():
+        if self.review_controller().is_question_showing() or \
+           self.review_controller().card.fact_view.a_on_top_of_q:
             frame = self.question.page().mainFrame()
         else:
             frame = self.answer.page().mainFrame()
@@ -284,7 +287,8 @@ class ReviewWdgt(QtGui.QWidget, QAOptimalSplit, Ui_ReviewWdgt, ReviewWidget):
         frame.evaluateJavaScript("window.scrollTo(%d, %d);" % (x, y))
 
     def scroll_up(self):
-        if self.review_controller().is_question_showing():
+        if self.review_controller().is_question_showing() or \
+           self.review_controller().card.fact_view.a_on_top_of_q:
             frame = self.question.page().mainFrame()
         else:
             frame = self.answer.page().mainFrame()
@@ -294,13 +298,14 @@ class ReviewWdgt(QtGui.QWidget, QAOptimalSplit, Ui_ReviewWdgt, ReviewWidget):
         frame.evaluateJavaScript("window.scrollTo(%d, %d);" % (x, y))
 
     def copy(self):
-        if self.review_controller().is_question_showing():
+        if self.review_controller().is_question_showing() or \
+           self.review_controller().card.fact_view.a_on_top_of_q:
             webview = self.question
         else:
             webview = self.answer
         webview.pageAction(QtWebKit.QWebPage.Copy).trigger()
 
-    def show_answer(self):
+    def show_answer(self):     
         self.review_controller().show_answer()
 
     def grade_answer(self, grade):
