@@ -529,6 +529,7 @@ class Client(Partner):
         self.ui.set_progress_value(total_size)
 
     def get_server_media_files(self, redownload_all=False):
+        self.ui.set_progress_text("Getting list of media files to download...")
         # Get list of names of all media files to download.
         media_url = "/server_media_filenames?session_token=%s" \
             % (self.server_info["session_token"], )
@@ -561,7 +562,8 @@ class Client(Partner):
             file_size = int(response.getheader("mnemosyne-content-length"))
             # Make sure a malicious server cannot overwrite anything outside
             # of the media directory.
-            filename = filename.replace("..", "")
+            filename = filename.replace("../", "").replace("..\\", "")
+            filename = filename.replace("/..", "").replace("\\..", "")
             filename = os.path.join(self.database.media_dir(), filename)
             self.download_binary_file(response, filename,
                                       file_size, progress_bar=False)
